Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch Rename xen_pmap_bootstrap to xen_locore, it really ...



details:   https://anonhg.NetBSD.org/src/rev/aa939f27c214
branches:  trunk
changeset: 348848:aa939f27c214
user:      maxv <maxv%NetBSD.org@localhost>
date:      Fri Nov 11 11:34:51 2016 +0000

description:
Rename xen_pmap_bootstrap to xen_locore, it really has nothing to do with
pmap and is just a C version of what amd64 and i386 do in asm.

diffstat:

 sys/arch/amd64/amd64/locore.S |  6 +++---
 sys/arch/i386/i386/locore.S   |  8 ++++----
 sys/arch/i386/i386/machdep.c  |  8 ++++----
 sys/arch/x86/x86/pmap.c       |  8 ++++----
 sys/arch/xen/x86/x86_xpmap.c  |  8 ++++----
 5 files changed, 19 insertions(+), 19 deletions(-)

diffs (161 lines):

diff -r 1a63f7043215 -r aa939f27c214 sys/arch/i386/i386/machdep.c
--- a/sys/arch/i386/i386/machdep.c      Fri Nov 11 11:31:26 2016 +0000
+++ b/sys/arch/i386/i386/machdep.c      Fri Nov 11 11:34:51 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.762 2016/09/25 12:59:19 maxv Exp $       */
+/*     $NetBSD: machdep.c,v 1.763 2016/11/11 11:34:51 maxv Exp $       */
 
 /*-
  * Copyright (c) 1996, 1997, 1998, 2000, 2004, 2006, 2008, 2009
@@ -67,7 +67,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.762 2016/09/25 12:59:19 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.763 2016/11/11 11:34:51 maxv Exp $");
 
 #include "opt_beep.h"
 #include "opt_compat_ibcs2.h"
@@ -993,7 +993,7 @@
        /*
         * We jumpstart the bootstrap process a bit so we can update
         * page permissions. This is done redundantly later from
-        * x86_xpmap.c:xen_pmap_bootstrap() - harmless.
+        * x86_xpmap.c:xen_locore() - harmless.
         */
        xpmap_phys_to_machine_mapping =
            (unsigned long *)xen_start_info.mfn_list;
@@ -1173,7 +1173,7 @@
 #if defined(PAE) && !defined(XEN)
        /*
         * Save VA and PA of L3 PD of boot processor (for Xen, this is done
-        * in xen_pmap_bootstrap())
+        * in xen_locore())
         */
        cpu_info_primary.ci_pae_l3_pdirpa = rcr3();
        cpu_info_primary.ci_pae_l3_pdir = (pd_entry_t *)(rcr3() + KERNBASE);
diff -r 1a63f7043215 -r aa939f27c214 sys/arch/x86/x86/pmap.c
--- a/sys/arch/x86/x86/pmap.c   Fri Nov 11 11:31:26 2016 +0000
+++ b/sys/arch/x86/x86/pmap.c   Fri Nov 11 11:34:51 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pmap.c,v 1.224 2016/11/11 09:47:18 maxv Exp $  */
+/*     $NetBSD: pmap.c,v 1.225 2016/11/11 11:34:51 maxv Exp $  */
 
 /*-
  * Copyright (c) 2008, 2010, 2016 The NetBSD Foundation, Inc.
@@ -171,7 +171,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.224 2016/11/11 09:47:18 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.225 2016/11/11 11:34:51 maxv Exp $");
 
 #include "opt_user_ldt.h"
 #include "opt_lockdebug.h"
@@ -512,7 +512,7 @@
 static pt_entry_t *csrc_pte, *cdst_pte, *zero_pte, *ptp_pte, *early_zero_pte;
 static char *csrcp, *cdstp, *zerop, *ptpp;
 #ifdef XEN
-char *early_zerop; /* also referenced from xen_pmap_bootstrap() */
+char *early_zerop; /* also referenced from xen_locore() */
 #else
 static char *early_zerop;
 #endif
@@ -1337,7 +1337,7 @@
                 * XXXfvdl fix this for MULTIPROCESSOR later.
                 */
 #ifdef XEN
-               /* early_zerop initialized in xen_pmap_bootstrap() */
+               /* early_zerop initialized in xen_locore() */
 #else
                early_zerop = (void *)(KERNBASE + NKL2_KIMG_ENTRIES * NBPD_L2);
 #endif
diff -r 1a63f7043215 -r aa939f27c214 sys/arch/xen/x86/x86_xpmap.c
--- a/sys/arch/xen/x86/x86_xpmap.c      Fri Nov 11 11:31:26 2016 +0000
+++ b/sys/arch/xen/x86/x86_xpmap.c      Fri Nov 11 11:34:51 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: x86_xpmap.c,v 1.64 2016/11/11 11:12:42 maxv Exp $      */
+/*     $NetBSD: x86_xpmap.c,v 1.65 2016/11/11 11:34:51 maxv Exp $      */
 
 /*
  * Copyright (c) 2006 Mathieu Ropert <mro%adviseo.fr@localhost>
@@ -68,7 +68,7 @@
 
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: x86_xpmap.c,v 1.64 2016/11/11 11:12:42 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: x86_xpmap.c,v 1.65 2016/11/11 11:34:51 maxv Exp $");
 
 #include "opt_xen.h"
 #include "opt_ddb.h"
@@ -122,7 +122,7 @@
 static void xen_bt_set_readonly(vaddr_t);
 static void xen_bootstrap_tables(vaddr_t, vaddr_t, size_t, size_t, int);
 
-vaddr_t xen_pmap_bootstrap(void);
+vaddr_t xen_locore(void);
 
 /*
  * kcpuset internally uses an array of uint32_t while xen uses an array of
@@ -596,7 +596,7 @@
  * tables.
  */
 vaddr_t
-xen_pmap_bootstrap(void)
+xen_locore(void)
 {
        size_t count, oldcount, mapsize;
        vaddr_t bootstrap_tables, init_tables;



Home | Main Index | Thread Index | Old Index
diff -r 1a63f7043215 -r aa939f27c214 sys/arch/amd64/amd64/locore.S
--- a/sys/arch/amd64/amd64/locore.S     Fri Nov 11 11:31:26 2016 +0000
+++ b/sys/arch/amd64/amd64/locore.S     Fri Nov 11 11:34:51 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: locore.S,v 1.112 2016/11/11 11:31:26 maxv Exp $        */
+/*     $NetBSD: locore.S,v 1.113 2016/11/11 11:34:51 maxv Exp $        */
 
 /*
  * Copyright-o-rama!
@@ -940,10 +940,10 @@
        movq    $1,%rsi
        call    cpu_init_msrs   /* cpu_init_msrs(ci, true); */
 
-       call    xen_pmap_bootstrap
+       call    xen_locore
 
        /*
         * The first VA available is returned by xen_pmap_bootstrap in %rax. We
         * use it as the UAREA, and set up the stack here.
         */
        movq    %rax,%rsi
@@ -940,10 +940,10 @@
 
        /*
-        * The first VA available is returned by xen_pmap_bootstrap in %rax. We
+        * The first VA available is returned by xen_locore in %rax. We
         * use it as the UAREA, and set up the stack here.
         */
diff -r 1a63f7043215 -r aa939f27c214 sys/arch/i386/i386/locore.S
--- a/sys/arch/i386/i386/locore.S       Fri Nov 11 11:31:26 2016 +0000
+++ b/sys/arch/i386/i386/locore.S       Fri Nov 11 11:34:51 2016 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: locore.S,v 1.139 2016/11/11 11:00:38 maxv Exp $        */
+/*     $NetBSD: locore.S,v 1.140 2016/11/11 11:34:51 maxv Exp $        */
 
 /*
  * Copyright-o-rama!
@@ -128,7 +128,7 @@
  */
 
 #include <machine/asm.h>
-__KERNEL_RCSID(0, "$NetBSD: locore.S,v 1.139 2016/11/11 11:00:38 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: locore.S,v 1.140 2016/11/11 11:34:51 maxv Exp $");
 
 #include "opt_compat_oldboot.h"
 #include "opt_copy_symtab.h"
@@ -917,10 +917,10 @@
        call    _C_LABEL(initgdt)
        addl    $4,%esp
 
-       call    xen_pmap_bootstrap
+       call    xen_locore
 
        /*
         * The first VA available is returned by xen_pmap_bootstrap in %eax. We
         * use it as the UAREA, and set up the stack here.
         */
        movl    %eax,%esi
@@ -917,10 +917,10 @@
 
        /*
-        * The first VA available is returned by xen_pmap_bootstrap in %eax. We
+        * The first VA available is returned by xen_locore in %eax. We
         * use it as the UAREA, and set up the stack here.
         */